==> ldapsaisie_1.0-8.tar.gz: ldapsaisie_clean/public_html/lang/fr_FR.UTF8/lang.php <==
<?php

$GLOBALS['LSlang'] = array (

"== All ==" =>
  "== Toutes ==",

"Accountable(s)" =>
  "Responsable(s)",

"Allow user to connect a POSIX system." =>
  "Autorisie l'utilisateur à se connecter aux systèmes POSIX.",

"Belongs to groups ..." =>
  "Appartient aux groupes ...",

"Civility" =>
  "Civilité",

"Command shell" =>
  "Interpréteur de commande",

"Companies" =>
  "Sociétés",

"Company" =>
  "Société",

"Description" =>
  "Description",

"Doesn't belong to any group." =>
  "N'appartient à aucun groupe.",

"E-mail address" =>
  "Adresse e-mail",

"File size is not valid." =>
  "La taille du fichier est invalide.",

"File type is not valid." =>
  "Le type de fichier est invalide.",

"First Name" =>
  "Prénom",

"Full Name" =>
  "Nom complet",

"Given email address is invalid." =>
  "L'adresse mail saisie est invalide.",

"Groups" =>
  "Groupes",

"Home Directory" =>
  "Dossier personnel",

"Identifier" =>
  "Identifiant",

"Identifier must contain alphanumeric values, dots (.) and dashes (-) only." =>
  "L'identifiant doit contenir uniquement des valeurs alpha-numériques, avec eventuellement des points (.) et des tirets (-).",

"LSexample" =>
  "LSexemple",

"LSexample - multi-company" =>
  "LSexemple - multi-société",

"LSexample : Recovering your password." =>
  "LSexemple : Récupération de votre mot de passe.",

"LSexample : Your new credentials." =>
  "LSexemple : Votre nouveau mot de passe.",

"Last Name" =>
  "Nom",

"Main group" =>
  "Groupe principal",

"Members" =>
  "Membres",

"Mr" =>
  "M.",

"Mrs" =>
  "Mms",

"Ms" =>
  "Mlle",

"Name" =>
  "Nom",

"Name must contain alphanumeric values only." =>
  "Le nom doit contenir uniquement des valeurs alpha-numériques.",

"Numeric identifier" =>
  "Identifiant numérique",

"One or several of these users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

"One or several users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

"Password" =>
  "Mot de passe",

"Password recovery hash" =>
  "Hash de récupération de mot de passe",

"Picture" =>
  "Image",

"Picture size is not valid." =>
  "La taille de l'image est invalide.",

"Posix" =>
  "Posix",

"Samba" =>
  "Samba",

"Samba Identifier" =>
  "Identifiant Samba",

"Samba Password (LM)" =>
  "Mot de passe Samba (LM)",

"Samba Password (NT)" =>
  "Mot de passe Samba (NT)",

"Simple" =>
  "Simple",

"The first name must contain alphanumeric values only." =>
  "Le prénom doit contenir uniquement des caractères alpha-numérique.",

"The numeric identifier must be an integer." =>
  "L'identifiant numérique doit forcement être un entier.",

"This group doesn't exist." =>
  "Ce groupe n'existe pas.",

"This identifier is already used." =>
  "Cet identifiant est déjà utilisé.",

"This uid is already used." =>
  "Cet uid est déjà utilisé.",

"To proceed password recovery procedure, please follow that link:
%{url}" =>
  "Pour poursuivre la procédure de récupération de mot de passe, merci de suivre ce lien :
%{url}",

"Users" =>
  "Utilisateurs",

"With photo" =>
  "Avec photo",

"Without photo" =>
  "Sans photo",

"Your new password : %{mdp}" =>
  "Votre nouveau mot de passe : %{mdp}",

"Your password has been changed.
Login : %{uid}
New password : %{password}" =>
  "Votre mot de passe a été changé.
Identifiant : %{uid}
Nouveau mot de passe : %{password}",

"Your password must contain from 8 to 10 characters." =>
  "Votre mot de passe doit contenir entre 8 et 10 caractères.",

);

?>

==> ldapsaisie_1.2-1.tar.gz: ldapsaisie_clean/public_html/lang/fr_FR.UTF8/lang.php <==
<?php

$GLOBALS['LSlang'] = array (

"== All ==" =>
  "== Toutes ==",

"Accountable(s)" =>
  "Responsable(s)",

"Allow user to connect a POSIX system." =>
  "Autorisie l'utilisateur à se connecter aux systèmes POSIX.",

"Belongs to groups ..." =>
  "Appartient aux groupes ...",

"Civility" =>
  "Civilité",

"Command shell" =>
  "Interpréteur de commande",

"Companies" =>
  "Sociétés",

"Company" =>
  "Société",

"Description" =>
  "Description",

"Doesn't belong to any group." =>
  "N'appartient à aucun groupe.",

"E-mail address" =>
  "Adresse e-mail",

"Errors" =>
  "Erreurs",

"File" =>
  "Fichier",

"File size is not valid." =>
  "La taille du fichier est invalide.",

"File type is not valid." =>
  "Le type de fichier est invalide.",

"First Name" =>
  "Prénom",

"Format" =>
  "Format",

"Full Name" =>
  "Nom complet",

"Given email address is invalid." =>
  "L'adresse mail saisie est invalide.",

"Groups" =>
  "Groupes",

"Home Directory" =>
  "Dossier personnel",

"Identifier" =>
  "Identifiant",

"Identifier must contain alphanumeric values, dots (.) and dashes (-) only." =>
  "L'identifiant doit contenir uniquement des valeurs alpha-numériques, avec eventuellement des points (.) et des tirets (-).",

"Imported objects" =>
  "Objets importés",

"LDAP Groups" =>
  "Groupes LDAP",

"LSexample" =>
  "LSexemple",

"LSexample - multi-company" =>
  "LSexemple - multi-société",

"LSexample : Recovering your password." =>
  "LSexemple : Récupération de votre mot de passe.",

"LSexample : Your new credentials." =>
  "LSexemple : Votre nouveau mot de passe.",

"Last Name" =>
  "Nom",

"Mail" =>
  "Mail",

"Main group" =>
  "Groupe principal",

"Members" =>
  "Membres",

"Mr" =>
  "M.",

"Mrs" =>
  "Mme",

"Ms" =>
  "Mlle",

"Name" =>
  "Nom",

"Name must contain alphanumeric values only." =>
  "Le nom doit contenir uniquement des valeurs alpha-numériques.",

"No imported object" =>
  "Aucun objet importé",

"No value" =>
  "Aucune valeur",

"Numeric identifier" =>
  "Identifiant numérique",

"One or several of these users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

"One or several users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

"Only validate data" =>
  "Validation des données uniquement",

"Password" =>
  "Mot de passe",

"Password recovery hash" =>
  "Hash de récupération de mot de passe",

"Picture" =>
  "Image",

"Picture size is not valid." =>
  "La taille de l'image est invalide.",

"Posix" =>
  "Posix",

"Result" =>
  "Résultat",

"Samba" =>
  "Samba",

"Samba Identifier" =>
  "Identifiant Samba",

"Samba Password (LM)" =>
  "Mot de passe Samba (LM)",

"Samba Password (NT)" =>
  "Mot de passe Samba (NT)",

"Simple" =>
  "Simple",

"The first name must contain alphanumeric values only." =>
  "Le prénom doit contenir uniquement des caractères alpha-numérique.",

"The numeric identifier must be an integer." =>
  "L'identifiant numérique doit forcement être un entier.",

"This group doesn't exist." =>
  "Ce groupe n'existe pas.",

"This identifier is already used." =>
  "Cet identifiant est déjà utilisé.",

"This uid is already used." =>
  "Cet uid est déjà utilisé.",

"To proceed password recovery procedure, please follow that link:
%{url}" =>
  "Pour poursuivre la procédure de récupération de mot de passe, merci de suivre ce lien :
%{url}",

"Update objects if exists" =>
  "Mettre à jour les objets existant",

"Updated objects" =>
  "Objets mis à jour",

"Users" =>
  "Utilisateurs",

"Valid" =>
  "Valide",

"With photo" =>
  "Avec photo",

"Without photo" =>
  "Sans photo",

"Your new password : %{mdp}" =>
  "Votre nouveau mot de passe : %{mdp}",

"Your password has been changed.
Login : %{uid}
New password : %{password}" =>
  "Votre mot de passe a été changé.
Identifiant : %{uid}
Nouveau mot de passe : %{password}",

"Your password must contain from 8 to 10 characters." =>
  "Votre mot de passe doit contenir entre 8 et 10 caractères.",

"no" =>
  "non",

"yes" =>
  "oui",

);
